@@ -2,13 +2,13 @@
 #define INCLUDED_AUDIOIO_TIMIDITY_H
 
 #include <string>
-#include "audioio-types.h"
-#include "samplebuffer.h"
+#include <cstdio>
+#include "audioio-buffered.h"
 #include "audioio-forked-stream.h"
 
 /**
- * Interface for MIDI-to-audio converters that support i/o using 
- * standard streams. By default, Timidity++ is used.
+ * Interface to MIDI-to-audio converters that support 
+ * UNIX pipe i/o. By default, Timidity++ is used.
  *
  * @author Kai Vehmanen
  */
@@ -17,30 +17,22 @@ class TIMIDITY_INTERFACE : public AUDIO_IO_BUFFERED,
 
  private:
   
-  static string default_timidity_cmd;
+  static std::string default_timidity_cmd;
 
  public:
 
-  static void set_timidity_cmd(const string& value);
+  static void set_timidity_cmd(const std::string& value);
 
- private:
-
-  bool triggered_rep;
-  bool finished_rep;
-  long int bytes_read_rep;
-  int fd_rep;
-  FILE* f1_rep;
-  
-  void seek_position_in_samples(long pos);
-  TIMIDITY_INTERFACE& operator=(const TIMIDITY_INTERFACE& x) { return *this; }
-
-  void fork_timidity(void);
-  void kill_timidity(void);
-  
  public:
 
-  virtual string name(void) const { return("MIDI-to-audio stream"); }
-  virtual string description(void) const { return("Interface for MIDI->audio converters that support i/o using standard streams."); }
+  TIMIDITY_INTERFACE (const std::string& name = "");
+  virtual ~TIMIDITY_INTERFACE(void);
+    
+  virtual TIMIDITY_INTERFACE* clone(void) const { return new TIMIDITY_INTERFACE(*this); }
+  virtual TIMIDITY_INTERFACE* new_expr(void) const { return new TIMIDITY_INTERFACE(); }
+
+  virtual std::string name(void) const { return("MIDI-to-audio stream"); }
+  virtual std::string description(void) const { return("Interface to MIDI-to-audio converters that support UNIX pipe i/o."); }
   virtual int supported_io_modes(void) const { return(io_read); }
   virtual bool supports_seeking(void) const { return(false); }
 
@@ -53,11 +45,19 @@ class TIMIDITY_INTERFACE : public AUDIO_IO_BUFFERED,
   virtual bool finished(void) const { return(finished_rep); }
   virtual void seek_position(void);
  
-  TIMIDITY_INTERFACE (const string& name = "");
-  ~TIMIDITY_INTERFACE(void);
-    
-  TIMIDITY_INTERFACE* clone(void) { return new TIMIDITY_INTERFACE(*this); }
-  TIMIDITY_INTERFACE* new_expr(void) { return new TIMIDITY_INTERFACE(); }
+ private:
+
+  bool triggered_rep;
+  bool finished_rep;
+  long int bytes_read_rep;
+  int filedes_rep;
+  FILE* f1_rep;
+  
+  void seek_position_in_samples(long pos);
+  TIMIDITY_INTERFACE& operator=(const TIMIDITY_INTERFACE& x) { return *this; }
+
+  void fork_timidity(void);
+  void kill_timidity(void);
 };
 
 #endif
