@@ -1,6 +1,6 @@
 // ------------------------------------------------------------------------
 // eca-chainsetup.cpp: Class representing an ecasound chainsetup object.
-// Copyright (C) 1999-2004 Kai Vehmanen
+// Copyright (C) 1999-2005 Kai Vehmanen
 // Copyright (C) 2005 Stuart Allie
 //
 // Attributes:
@@ -62,6 +62,7 @@
 #include "audioio-buffered.h"
 #include "audioio-loop.h"
 #include "audioio-null.h"
+#include "audioio-resample.h"
 
 #include "eca-engine-driver.h"
 #include "eca-object-factory.h"
@@ -1800,7 +1801,11 @@ void ECA_CHAINSETUP::enable(void) throw(ECA_ERROR&)
 
       /* 6. enable the MIDI server */
       if (impl_repp->midi_server_rep.is_enabled() != true &&
-	  midi_devices.size() > 0) impl_repp->midi_server_rep.enable();
+	  midi_devices.size() > 0) {
+	impl_repp->midi_server_rep.set_schedrealtime(raised_priority());
+	impl_repp->midi_server_rep.set_schedpriority(get_sched_priority());
+	impl_repp->midi_server_rep.enable();
+      }
 
       /* 7. enable all MIDI-devices */
       for(vector<MIDI_IO*>::iterator q = midi_devices.begin(); q != midi_devices.end(); q++) {
@@ -1929,16 +1934,25 @@ long int ECA_CHAINSETUP::check_for_locked_buffersize(void) const
 #ifdef ECA_COMPILE_JACK
   int pid = getpid();
   string cname = "ecasound-ctrl-" + kvu_numtostr(pid);
-  int jackobjs = 0;
+  int jackobjs = 0, resampleobjs = 0;
 
   for(size_t n = 0; n < inputs_direct_rep.size(); n++) {
-    if (inputs_direct_rep[n]->name() == "JACK interface") {
-      ++jackobjs;
-      break;
-    }
+    AUDIO_IO_RESAMPLE *p = dynamic_cast<AUDIO_IO_RESAMPLE*>(inputs_direct_rep[n]);
+    if (p != 0) ++resampleobjs;
+    if (inputs_direct_rep[n]->name() == "JACK interface") ++jackobjs;
+    if (resampleobjs && jackobjs) break;
   }
-  for(size_t n = 0; jackobjs == 0 && n < outputs_direct_rep.size(); n++) {
+  for(size_t n = 0; n < outputs_direct_rep.size(); n++) {
+    AUDIO_IO_RESAMPLE *p = dynamic_cast<AUDIO_IO_RESAMPLE*>(outputs_direct_rep[n]);
+    if (p != 0) ++resampleobjs;
     if (outputs_direct_rep[n]->name() == "JACK interface") ++jackobjs;
+    if (resampleobjs && jackobjs) break;
+  }
+
+  if (resampleobjs && jackobjs) {
+    ECA_LOG_MSG(ECA_LOGGER::info, 
+		"WARNING: Mixing resample and jack objects may result garbled audio. "
+		"Problem occurs when buffersize is not an integer multiple of resample ratio.");
   }
 
   /* contact jackd only if there is at least one jack audio object 
