@@ -1,6 +1,9 @@
 // ------------------------------------------------------------------------
 // midi-server.cpp: MIDI i/o engine serving generic clients.
-// Copyright (C) 2001-2002 Kai Vehmanen
+// Copyright (C) 2001-2002,2005 Kai Vehmanen
+//
+// Attributes:
+//     eca-style-version: 3
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -26,12 +29,10 @@
 #include <unistd.h>
 #include <signal.h>
 #include <sys/time.h>
-#ifdef HAVE_SCHED_H
-#include <sched.h>
-#endif
 
 #include <kvu_numtostr.h>
 #include <kvu_dbc.h>
+#include <kvu_rtcaps.h>
 
 #include "midi-parser.h"
 #include "midi-server.h"
@@ -51,8 +52,19 @@ void* start_midi_server_io_thread(void *ptr)
 
   MIDI_SERVER* mserver =
     static_cast<MIDI_SERVER*>(ptr);
+
+  if (mserver->schedrealtime_rep == true) {
+    if (kvu_set_thread_scheduling(SCHED_FIFO, mserver->schedpriority_rep) != 0)
+      ECA_LOG_MSG(ECA_LOGGER::system_objects, "Unable to change scheduling policy!");
+    else
+      ECA_LOG_MSG(ECA_LOGGER::info, 
+		  std::string("Using realtime-scheduling (SCHED_FIFO:") + kvu_numtostr(mserver->schedpriority_rep) + ").");
+  }
+
+  /* launch the worker thread */
   mserver->io_thread();
-  return(0);
+
+  return 0;
 }
 
 /**
@@ -61,10 +73,10 @@ void* start_midi_server_io_thread(void *ptr)
 void MIDI_SERVER::io_thread(void)
 {
   fd_set fds;
-  unsigned char buf[3];
+  unsigned char buf[16];
   struct timeval tv;
   
-  ECA_LOG_MSG(ECA_LOGGER::user_objects, "(midi-server) Hey, in the I/O loop!");
+  ECA_LOG_MSG(ECA_LOGGER::user_objects, "Hey, in the I/O loop!");
   while(true) {
     if (running_rep.get() == 0 ||
 	clients_rep[0]->is_open() != true) {
@@ -75,6 +87,10 @@ void MIDI_SERVER::io_thread(void)
 
     DBC_CHECK(clients_rep.size() > 0);
     DBC_CHECK(clients_rep[0]->supports_nonblocking_mode() == true);
+
+    // FIXME: add support for multiple clients; gather poll
+    //        descriptors from all clients and create the 'fds' set
+
     int fd = clients_rep[0]->poll_descriptor();
 
     FD_ZERO(&fds);
@@ -84,18 +100,20 @@ void MIDI_SERVER::io_thread(void)
     tv.tv_usec = 0;
     int retval = select(fd + 1 , &fds, NULL, NULL, &tv);
 
+    // FIXME: add multiple client support, go through 
+    //        all the fds
+
     int read_bytes = 0;
     if (retval) {
       if (FD_ISSET(fd, &fds) == true) {
-	// FIXME:: should use MIDI_IO::write_bytes() instead,
-	//         poll_descriptor is only meant for poll() and select()
-	read_bytes = ::read(fd, buf, 1);
+	read_bytes = clients_rep[0]->read_bytes(buf, 16);
+	//std::cerr << "TRACE: Read from MIDI-device (bytes): " << read_bytes << "." << std::endl;
       }
     }
 
     if (read_bytes < 0) {
       std::cerr << "ERROR: Can't read from MIDI-device: " 
-	   << clients_rep[0]->label() << "." << std::endl;
+		<< clients_rep[0]->label() << "." << std::endl;
       break;
     }
     else {
@@ -119,7 +137,7 @@ void MIDI_SERVER::io_thread(void)
       running_rep.set(0);
     }
   }
-  ECA_LOG_MSG(ECA_LOGGER::system_objects, "(midi-server) exiting MIDI-server thread");
+  ECA_LOG_MSG(ECA_LOGGER::system_objects, "exiting MIDI-server thread");
 }
 
 /**
@@ -154,7 +172,7 @@ void MIDI_SERVER::start(void)
 {
   stop_request_rep.set(0);
   running_rep.set(1);
-  ECA_LOG_MSG(ECA_LOGGER::user_objects, "(midi-server) starting processing");
+  ECA_LOG_MSG(ECA_LOGGER::user_objects, "starting processing");
   send_mmc_start();
   if (is_midi_sync_send_enabled() == true) send_midi_start();
 
@@ -171,7 +189,7 @@ void MIDI_SERVER::start(void)
 void MIDI_SERVER::stop(void)
 {
   stop_request_rep.set(1);
-  ECA_LOG_MSG(ECA_LOGGER::user_objects, "(midi-server) stopping processing");
+  ECA_LOG_MSG(ECA_LOGGER::user_objects, "stopping processing");
   send_mmc_stop();
   if (is_midi_sync_send_enabled() == true) send_midi_stop();
 }
@@ -188,7 +206,12 @@ void MIDI_SERVER::init(void)
 }
 
 /**
- * Enables the MIDI-server subsystems and prepared them for processing. 
+ * Enables the MIDI-server subsystems and prepared them for
+ * processing. 
+ *
+ * Use the set_schedrealtime() and set_schedpriority() functions
+ * to set the MIDI subsystem scheduling priority. These settings
+ * are set at enable().
  * 
  * ensure:
  *  is_enabled() == true
@@ -200,29 +223,15 @@ void MIDI_SERVER::enable(void)
   stop_request_rep.set(0);
   exit_request_rep.set(0);
   if (thread_running_rep != true) {
-    ECA_LOG_MSG(ECA_LOGGER::user_objects, "(midi-server) enabling");
+    ECA_LOG_MSG(ECA_LOGGER::user_objects, "enabling");
     int ret = pthread_create(&io_thread_rep,
 			     0,
 			     start_midi_server_io_thread,
 			     static_cast<void *>(this));
     if (ret != 0) {
-      ECA_LOG_MSG(ECA_LOGGER::info, "(midi-server) pthread_create failed, exiting");
+      ECA_LOG_MSG(ECA_LOGGER::info, "pthread_create failed, exiting");
       exit(1);
     }
-#ifdef HAVE_SCHED_GETSCHEDULER
-    if (sched_getscheduler(0) == SCHED_FIFO) {
-#ifdef HAVE_PTHREAD_SETSCHEDPARAM
-      struct sched_param sparam;
-      sparam.sched_priority = schedpriority_rep;
-      if (::pthread_setschedparam(io_thread_rep, SCHED_FIFO, &sparam) != 0)
-	ECA_LOG_MSG(ECA_LOGGER::info, "Unable to change scheduling policy to SCHED_FIFO!");
-      else 
-	ECA_LOG_MSG(ECA_LOGGER::info, "Using realtime-scheduling (SCHED_FIFO).");
-#endif
-    }
-#else
-	ECA_LOG_MSG(ECA_LOGGER::info, "WARNING: Functions to query scheduler settings not available!");
-#endif
     thread_running_rep = true;
   }
 
@@ -234,7 +243,7 @@ void MIDI_SERVER::enable(void)
 /**
  * Whether MIDI-server is enabled?
  */
-bool MIDI_SERVER::is_enabled(void) const { return(thread_running_rep); }
+bool MIDI_SERVER::is_enabled(void) const { return thread_running_rep; }
 
 /**
  * Disables the MIDI-server subsystems.
@@ -252,7 +261,7 @@ void MIDI_SERVER::disable(void)
   DBC_REQUIRE(is_enabled() == true);
   // --------
 
-  ECA_LOG_MSG(ECA_LOGGER::user_objects, "(midi-server) disabling");
+  ECA_LOG_MSG(ECA_LOGGER::user_objects, "disabling");
   stop_request_rep.set(1);
   exit_request_rep.set(1);
   if (thread_running_rep == true) {
@@ -271,8 +280,8 @@ void MIDI_SERVER::disable(void)
  */
 bool MIDI_SERVER::is_running(void) const
 {
-  if (running_rep.get() == 0) return(false); 
-  return(true);
+  if (running_rep.get() == 0) return false; 
+  return true;
 }
 
 /**
@@ -365,11 +374,8 @@ void MIDI_SERVER::send_midi_bytes(int dev_id, unsigned char* buf, int bytes) {
     DBC_CHECK(static_cast<int>(clients_rep.size()) >= dev_id);
     DBC_CHECK(clients_rep[dev_id - 1]->supports_nonblocking_mode() == true);
 
-    int fd = clients_rep[dev_id - 1]->poll_descriptor();
+    int err = clients_rep[dev_id - 1]->write_bytes(buf, bytes);
 
-    // FIXME:: should use MIDI_IO::write_bytes() instead,
-    //         poll_descriptor is only meant for poll() and select()
-    int err = ::write(fd, buf, bytes);
     DBC_CHECK(err == bytes);
   }
 }
@@ -389,7 +395,7 @@ void MIDI_SERVER::send_mmc_command(unsigned int cmd)
   std::list<int>::const_iterator p = mmc_send_ids_rep.begin();
   while(p != mmc_send_ids_rep.end()) {
     ECA_LOG_MSG(ECA_LOGGER::system_objects, 
-		"(midi-server) Sending MMC message " + 
+		"Sending MMC message " + 
 		kvu_numtostr(cmd) + " to device-id " +
 		kvu_numtostr(*p) + ".");
     buf[2] = static_cast<unsigned char>(*p);
@@ -424,7 +430,7 @@ void MIDI_SERVER::send_midi_start(void)
   unsigned char byte[1] = { 0xfa };
 
   ECA_LOG_MSG(ECA_LOGGER::system_objects, 
-	      "(midi-server) Sending MIDI-start message.");
+	      "Sending MIDI-start message.");
 
   send_midi_bytes(1, byte, 1);
 }
@@ -437,7 +443,7 @@ void MIDI_SERVER::send_midi_continue(void)
   unsigned char byte[1] = { 0xfb };
 
   ECA_LOG_MSG(ECA_LOGGER::system_objects, 
-	      "(midi-server) Sending MIDI-continue message.");
+	      "Sending MIDI-continue message.");
 
   send_midi_bytes(1, byte, 1);
 }
@@ -450,7 +456,7 @@ void MIDI_SERVER::send_midi_stop(void)
   unsigned char byte[1] = { 0xfc };
 
   ECA_LOG_MSG(ECA_LOGGER::system_objects, 
-	      "(midi-server) Sending MIDI-stop message.");
+	      "Sending MIDI-stop message.");
 
   send_midi_bytes(1, byte, 1);
 }
@@ -484,9 +490,9 @@ int MIDI_SERVER::last_controller_value(int channel, int ctrl) const
 {
   std::map<std::pair<int,int>,int>::iterator p = controller_values_rep.find(std::pair<int,int>(channel,ctrl));
   if (p != controller_values_rep.end()) {
-    return(controller_values_rep[std::pair<int,int>(channel,ctrl)]);
+    return controller_values_rep[std::pair<int,int>(channel,ctrl)];
   }
-  return(0);
+  return 0;
 }
 
 /**
@@ -528,10 +534,9 @@ void MIDI_SERVER::parse_receive_queue(void)
 	    if (controller_values_rep.find(std::pair<int,int>(current_ctrl_channel_rep,current_ctrl_number)) 
 		!= controller_values_rep.end()) {
 	      controller_values_rep[std::pair<int,int>(current_ctrl_channel_rep,current_ctrl_number)] = static_cast<int>(byte);
-	      // cerr << endl << "(midi-server) Value:" 
-	      //      << controller_values_rep[pair<int,int>(current_ctrl_channel_rep,current_ctrl_number)] 
-	      //      << ", ch:" << current_ctrl_channel_rep 
-	      //      << ", ctrl:" << current_ctrl_number << ".";
+	      // std::cerr << std::endl << "(midi-server) Value:" 
+	      //      << controller_values_rep[std::pair<int,int>(current_ctrl_channel_rep,current_ctrl_number)] 
+	      //      << ", ch:" << current_ctrl_channel_rep << ", ctrl:" << current_ctrl_number << ".";
 	    }
 	    // else {
 	    //   cerr << endl << "E:" << " found an entry we are not following..." << endl;
